@@ -187,7 +187,16 @@ class SpeechServer(speechserver.SpeechServer):
             style = 'spell'
         else:
             style = 'none'
-        self._client.set_cap_let_recogn(style)
+
+        try:
+            self._client.set_cap_let_recogn(style)
+        except speechd.SSIPCommunicationError:
+            msg = "SPEECH DISPATCHER: Connection lost. Trying to reconnect."
+            debug.println(debug.LEVEL_INFO, msg, True)
+            self.reset()
+            self._client.set_cap_let_recogn(style)
+        except:
+            pass
 
     def updatePunctuationLevel(self):
         """ Punctuation level changed, inform this speechServer. """
@@ -195,19 +204,15 @@ class SpeechServer(speechserver.SpeechServer):
         self._client.set_punctuation(mode)
 
     def _send_command(self, command, *args, **kwargs):
-        if hasattr(speechd, 'SSIPCommunicationError'):
-            try:
-                return command(*args, **kwargs)
-            except speechd.SSIPCommunicationError:
-                msg = "SPEECH DISPATCHER: Connection lost. Trying to reconnect."
-                debug.println(debug.LEVEL_INFO, msg, True)
-                self.reset()
-                return command(*args, **kwargs)
-            except:
-                pass
-        else:
-            # It is not possible tho catch the error with older SD versions. 
+        try:
             return command(*args, **kwargs)
+        except speechd.SSIPCommunicationError:
+            msg = "SPEECH DISPATCHER: Connection lost. Trying to reconnect."
+            debug.println(debug.LEVEL_INFO, msg, True)
+            self.reset()
+            return command(*args, **kwargs)
+        except:
+            pass
 
     def _set_rate(self, acss_rate):
         rate = int(2 * max(0, min(99, acss_rate)) - 98)
@@ -535,7 +540,7 @@ class SpeechServer(speechserver.SpeechServer):
         # set according to the current locale.
         from locale import getlocale, LC_MESSAGES
         locale = getlocale(LC_MESSAGES)[0]
-        if locale is None or locale == 'C':
+        if locale is None or not '_' in locale:
             locale_language = None
         else:
             locale_lang, locale_dialect = locale.split('_')
@@ -581,6 +586,12 @@ class SpeechServer(speechserver.SpeechServer):
         return families
 
     def speak(self, text=None, acss=None, interrupt=True):
+        # In order to re-enable this, a potentially non-trivial amount of work
+        # will be needed to ensure multiple utterances sent to speech.speak
+        # do not result in the intial utterances getting cut off before they
+        # can be heard by the user. Anyone needing to interrupt speech can
+        # do so via speech.stop -- or better yet, by using the default script
+        # method's presentationInterrupt.
         #if interrupt:
         #    self._cancel()
 
@@ -595,6 +606,12 @@ class SpeechServer(speechserver.SpeechServer):
             self._speak(text, acss)
 
     def speakUtterances(self, utteranceList, acss=None, interrupt=True):
+        # In order to re-enable this, a potentially non-trivial amount of work
+        # will be needed to ensure multiple utterances sent to speech.speak
+        # do not result in the intial utterances getting cut off before they
+        # can be heard by the user. Anyone needing to interrupt speech can
+        # do so via speech.stop -- or better yet, by using the default script
+        # method's presentationInterrupt.
         #if interrupt:
         #    self._cancel()
         for utterance in utteranceList:
